#
# spec file for package xscope
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xscope
Version:        1.4.4
Release:        1.5
Summary:        Utility to monitor X11/Client conversations
License:        MIT
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xtrans)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
XSCOPE is a program to monitor the connections between the X11 window
server and a client program.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog NEWS README.md
%license COPYING
%{_bindir}/xscope
%{_mandir}/man1/xscope.1%{?ext_man}

%changelog
* Sat Jun 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.4
  * This release fixes some minor bugs and adds support for decoding
    the DAMAGE extension.
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.3
  * On OpenBSD SO_PEERCRED uses struct sockpeercred
  * Remove/comment out unused variables.
  * Match format strings with arguments.
  * ifdef out unused static functions
  * Use correct argument type for ctype(3) functions.
  * Increase buffer length to avoid truncation.
  * Add casts to fix signedness change warnings.
  * Mark MainLoop as _X_NORETURN.
* Tue Dec  7 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.2
  * This version adds support for printing the process IDs and
    names of local clients and servers on systems supporting /proc
    and either SO_PEERCRED or getpeerucred().
* Tue Jun 10 2014 sndirsch@suse.com
- Update to version 1.4.1
  * This version corrects several bugs which caused xscope to incorrectly
    decode some protocol replies or events, and fixes a build issue on Solaris.
* Sat Jan 19 2013 zaitor@opensuse.org
- Update to version 1.4:
  + RANDR decoding updated from just 0.x protocol to handle
    1.0 - 1.4
  + Atoms recorded from InternAtom & GetAtomName to use for display
    in other requests referencing the atoms
  + Property requests now also show these property types in a more
    natural format instead of as just lists of bytes:
  + New -I command line flag to enter interactive mode immediately
    at startup
  + Experimental support for reading a previously recorded file.
    If you run "xscope -r -v0 > xscope.raw", then you can later run
    "xscope -f xscope.raw" to decode the data.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.3.1:
  + Add const attributes to clear gcc -Wwrite-strings warnings
  + Add Intel copyright to COPYING for glx additions in xscope 1.3
  + Allocate buffers dynamically as needed instead of as part of
    fdinfo struct
  + Call realloc() instead of open coding it
  + Check the right return value for malloc failure
  + Clean up existing malloc calls
  + Ensure ScopeHost global is initialized when built with
    USE_XTRANS
  + File descriptors should be stored in ints not shorts
  + Fix builds of scope.c with Solaris Studio compilers
  + Make CS dynamically allocated
  + Make FDinfo dynamically allocated
  + Make ReplyQ dynamically allocated
  + Mark panic() as _X_NORETURN
  + Remove extra definition of ScopeEnabled from x11.h
  + Remove StaticMaxFD now that all uses now allocate dynamically
  + Remove unused variable server_client from print_lbx.c
  + Stop wrapping malloc & free
  + Store ClientNumber as int instead of converting back & forth to
    long
  + Use calloc() instead of malloc(); bzero();
  + Use strdup instead of malloc(strlen+1); strcpy();
  + Build system fixes
- Add pkgconfig(xproto) BuildRequires: New upstream dependency.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xscope from xorg-x11. Initial version: 1.3.
